/**
 * Merges two arrays, one of `ColDef` and one of `ColumnState`, and deduplicates them.
 * @remarks ColDef uses `field` and ColumnState uses `colId` to identify columns.
 * @privateRemarks For restoring saved `ColumnState` but also keep custom renderers and other `ColDef` properties.
 * @public
 */
export function mergeAndDeduplicateColDefAndState(arr1, arr2, arr1Field = 'field', arr2Field = 'colId') {
    const merged = {};
    const deduplicated = [];
    arr2.forEach((obj) => {
        const matchingObj = arr1.find((item) => item[arr1Field] === obj[arr2Field]);
        if (matchingObj) {
            const newObj = Object.assign(Object.assign({}, matchingObj), { [arr2Field]: obj[arr2Field] });
            merged[matchingObj[arr1Field]] = newObj;
            deduplicated.push(newObj);
        }
    });
    arr1.forEach((obj) => {
        if (!merged.hasOwnProperty(obj[arr1Field])) {
            const newObj = Object.assign({}, obj);
            merged[obj[arr1Field]] = newObj;
            deduplicated.push(newObj);
        }
    });
    return deduplicated;
}
